@@ -19,15 +19,11 @@ import           Control.Monad.Trans          (liftIO)
 import           Control.Monad.Trans.Resource (runResourceT)
 import           Data.List                    (isPrefixOf)
 import qualified Data.Map.Lazy                as Map
-#if MIN_VERSION_base(4,9,0)
-import           Data.Semigroup               (Semigroup (..))
-#endif
 import           Network.URI                  (unEscapeString)
 import           System.Directory             (doesDirectoryExist,
                                                doesFileExist)
 import           System.Exit                  (ExitCode (..))
-import           System.FilePath              (takeDirectory, takeExtension,
-                                               (</>))
+import           System.FilePath              (takeDirectory, (</>))
 import qualified Text.HTML.TagSoup            as TS
 
 
@@ -88,7 +84,6 @@ data CheckerWrite = CheckerWrite
 
 
 --------------------------------------------------------------------------------
-#if MIN_VERSION_base(4,9,0)
 instance Semigroup CheckerWrite where
     (<>) (CheckerWrite f1 o1) (CheckerWrite f2 o2) =
         CheckerWrite (f1 + f2) (o1 + o2)
@@ -96,12 +91,6 @@ instance Semigroup CheckerWrite where
 instance Monoid CheckerWrite where
     mempty  = CheckerWrite 0 0
     mappend = (<>)
-#else
-instance Monoid CheckerWrite where
-    mempty                                            = CheckerWrite 0 0
-    mappend (CheckerWrite f1 o1) (CheckerWrite f2 o2) =
-        CheckerWrite (f1 + f2) (o1 + o2)
-#endif
 
 
 --------------------------------------------------------------------------------
@@ -139,7 +128,7 @@ checkDestination = do
     let htmls =
             [ destinationDirectory config </> file
             | file <- files
-            , takeExtension file == ".html"
+            , checkHtmlFile config file
             ]
 
     forM_ htmls checkFile
