@@ -4,9 +4,6 @@ module Hakyll.Web.Pandoc.Binary where
 
 import           Data.Binary        (Binary (..))
 
-import qualified Text.CSL           as CSL
-import qualified Text.CSL.Reference as REF
-import qualified Text.CSL.Style     as STY
 import           Text.Pandoc
 
 --------------------------------------------------------------------------------
@@ -14,7 +11,10 @@ import           Text.Pandoc
 
 instance Binary Alignment
 instance Binary Block
-instance Binary CSL.Reference
+instance Binary Caption
+instance Binary Cell
+instance Binary ColSpan
+instance Binary ColWidth
 instance Binary Citation
 instance Binary CitationMode
 instance Binary Format
@@ -23,11 +23,9 @@ instance Binary ListNumberDelim
 instance Binary ListNumberStyle
 instance Binary MathType
 instance Binary QuoteType
-instance Binary REF.CLabel
-instance Binary REF.CNum
-instance Binary REF.Literal
-instance Binary REF.RefDate
-instance Binary REF.RefType
-instance Binary REF.Season
-instance Binary STY.Agent
-instance Binary STY.Formatted
+instance Binary Row
+instance Binary RowHeadColumns
+instance Binary RowSpan
+instance Binary TableBody
+instance Binary TableFoot
+instance Binary TableHead
